@@ -3,19 +3,24 @@ from .render.trees import (
     build, initConfig,
 )
 
-from .render.demo import demo_symbols, demo_themes, colorTable
+from .render.demo import (
+    print_demo, demo_symbols, demo_themes,
+    colorTable, themeTable, symbolTable, extrasTable,
+    render_file_demo
+)
 
 from .render.theme import (
     initConfig, convertTheme, check_none, lnode
 )
 
 from .render.funcs import (
-    try_all, rich_func, rich_func_chainer,
+    call_any, rich_func, rich_func_chainer,
     format_user_theme, apply_progress_theme,
 )
 
 from .render.tables import (
-    tableFromRecords, treeThemeToTable, recordFormatting,
+    tableFromRecords, treeThemeToTable,
+    recordFormatting
     
 )
 
@@ -24,4 +29,6 @@ from .render.trees import (
 )
 
 from .io.reader import read_file, read_dir, read
-from .io.writer import write_file, write_dir, write
\ No newline at end of file
+from .io.writer import write_file, write_dir, write
+from .io.serialize import dumps
+from .io.internals import format_dict
\ No newline at end of file
