@@ -1,5 +1,5 @@
 from .funcs import (
-    try_all, rich_func, rich_func_chainer,
+    call_any, rich_func, rich_func_chainer,
     format_user_theme, apply_progress_theme,
 )
 
@@ -17,5 +17,10 @@ from .theme import (
 )
 
 from .demo import (
-    print_demo, demo_symbols, demo_themes, colorTable, themeTable
-)
\ No newline at end of file
+    print_demo, demo_symbols, demo_themes,
+    colorTable, themeTable, symbolTable, extrasTable,
+    render_file_demo
+)
+
+from ..io import reader, writer, serialize
+
